@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """Top-level package for soft_search."""
 
 from importlib.metadata import PackageNotFoundError, version
@@ -10,4 +8,4 @@ except PackageNotFoundError:
     __version__ = "uninstalled"
 
 __author__ = "Eva Maxfield Brown"
-__email__ = "jmxbrown@uw.edu"
+__email__ = "evamxb@uw.edu"
