@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 from datetime import datetime
 from typing import List, Union
@@ -9,26 +8,25 @@ import pytest
 from soft_search.constants import NSFFields
 from soft_search.nsf import get_nsf_dataset
 
+
 ###############################################################################
 
 
 @pytest.mark.parametrize(
-    "start_date, end_date, dataset_fields, expected_length",
+    "start_date, end_date, dataset_fields",
     [
-        ("2017-01-01", "2017-06-01", [NSFFields.id_, NSFFields.abstractText], 27),
-        ("01/01/2018", "01/01/2019", [NSFFields.id_, NSFFields.title], 38),
+        ("2017-01-01", "2017-02-01", [NSFFields.id_, NSFFields.abstractText]),
+        ("01/01/2018", "02/01/2018", [NSFFields.id_, NSFFields.title]),
         (
             datetime(2019, 1, 1),
-            datetime(2020, 1, 1),
+            datetime(2019, 2, 1),
             [NSFFields.id_, NSFFields.projectOutComesReport],
-            28,
         ),
         # Fails because weird date format
         pytest.param(
             "2017 01 01",
             "2019 01 01",
-            [NSFFields.id_, NSFFields.abstractText],
-            10,
+            None,
             marks=pytest.mark.raises(exception=ValueError),
         ),
     ],
@@ -37,7 +35,6 @@ def test_get_nsf_dataset(
     start_date: Union[str, datetime],
     end_date: Union[str, datetime],
     dataset_fields: List[str],
-    expected_length: int,
 ) -> None:
     df = get_nsf_dataset(
         start_date=start_date,
@@ -45,4 +42,6 @@ def test_get_nsf_dataset(
         dataset_fields=dataset_fields,
     )
     assert all([col in dataset_fields for col in df.columns])
-    assert len(df) == expected_length
+    # Note: we used to check expected length but the NSF API is flakey
+    # API returns duplicate awards (by id) and when we drop duplicates
+    # it sometimes differs based on the return order
